@@ -470,6 +470,16 @@ class AquaLogic():
         are in Metric."""
         return self._is_metric
 
+    @property
+    def is_heater_enabled(self):
+        """Returns True if HEATER_1 is on"""
+        return self.get_state(States.HEATER_1)
+
+    @property
+    def is_super_chlorinate_enabled(self):
+        """Returns True if super chlorinate is on"""
+        return self.get_state(States.SUPER_CHLORINATE)
+
     def states(self):
         """Returns a set containing the enabled states."""
         state_list = []
